==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPaneCloseEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPaneCloseEventArgsDetailDescription } from "./WebPaneCloseEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPaneCloseEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneCloseEventArgsDetailDescriptionMetadata, _super);
    function WebPaneCloseEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneCloseEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPaneCloseEventArgsDetailDescriptionMetadata.a == null) {
            WebPaneCloseEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneCloseEventArgsDetailDescriptionMetadata.c(WebPaneCloseEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPaneCloseEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPaneCloseEventArgsDetailDescriptionMetadata.a);
        WebDockManagerPaneDescriptionMetadata.d(a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebPaneCloseEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneCloseEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("SourcePane", "ExportedType:WebDockManagerPane");
        a.item("Panes", "Array:WebContentPaneDescription:ContentPane");
    };
    WebPaneCloseEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPaneCloseEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebPaneCloseEventArgsDetail", function () { return new WebPaneCloseEventArgsDetailDescription(); });
        a.ac("WebPaneCloseEventArgsDetail", WebPaneCloseEventArgsDetailDescriptionMetadata.a);
    };
    WebPaneCloseEventArgsDetailDescriptionMetadata.$t = markType(WebPaneCloseEventArgsDetailDescriptionMetadata, 'WebPaneCloseEventArgsDetailDescriptionMetadata');
    WebPaneCloseEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPaneCloseEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebPaneCloseEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneCloseEventArgsDetailDescription } from "./WebPaneCloseEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPaneCloseEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneCloseEventArgsDetailDescriptionMetadata, _super);
    function WebPaneCloseEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneCloseEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPaneCloseEventArgsDetailDescriptionMetadata.a == null) {
            WebPaneCloseEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneCloseEventArgsDetailDescriptionMetadata.c(WebPaneCloseEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPaneCloseEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPaneCloseEventArgsDetailDescriptionMetadata.a);
        WebDockManagerPaneDescriptionMetadata.d(a);
    };
    WebPaneCloseEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneCloseEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("SourcePane", "ExportedType:WebDockManagerPane");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
    };
    WebPaneCloseEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPaneCloseEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebPaneCloseEventArgsDetail", function () { return new WebPaneCloseEventArgsDetailDescription(); });
        a.ad("WebPaneCloseEventArgsDetail", WebPaneCloseEventArgsDetailDescriptionMetadata.a);
    };
    WebPaneCloseEventArgsDetailDescriptionMetadata.$t = markType(WebPaneCloseEventArgsDetailDescriptionMetadata, 'WebPaneCloseEventArgsDetailDescriptionMetadata');
    WebPaneCloseEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPaneCloseEventArgsDetailDescriptionMetadata };
